@@ -131,8 +131,8 @@ function(model,parameter,beta=NULL,se=FALSE,design=NULL,data=NULL,vcv=FALSE,show
   model=load.model(model)
   if(is.null(model$results)) 
   {
-     message("Model output is not available\n")
-     invisible()
+	  message(paste("Model output is not available in R. Check contents of ",model$output, ".out\n",sep=""))
+	  invisible()
   }
 #
 # Next make sure that requested parameter is appropriate
